
from .cases import MockedTestCase

class TestEndpointUrls(MockedTestCase):

    def test_submit_cancel_order(self):
        # https://github.com/ericls/huobi/issues/1
        self.client.submit_cancel(order_id='1234')
        self.assertIn('/1234/', self.last_url)
        self.client.submit_cancel(order_id='2345')
        self.assertIn('/2345/', self.last_url)



"""
class of Huobi restful api client, common endpoints
"""
from huobi.rest.endpoints import HuobiRestClientBase
from huobi.rest.endpoint import Endpoint


class HuobiRestClientCommon(HuobiRestClientBase):
    """
    Huobi restful api client
    """

    symbols = Endpoint(
        method='GET',
        path='/v1/common/symbols',
        auth_required=False,
    )

    currencys = currencies = Endpoint(
        method='GET',
        path='/v1/common/currencys'
    )

    timestamp = Endpoint(
        method='GET',
        path='/v1/common/timestamp',
        auth_required=False,
    )



from huobi.rest.error import HuobiRestiApiError, HuobiRestRequestError
from .cases import MockedTestCase


class TestHandleResponse(MockedTestCase):

    def test_400(self):
        # 400 series is client side error. Server will likely return helpful error message
        # Do not thorw Request Error, throw ApiError instead
        self.mocked_respnse_status_code = 403
        self.mocked_respnse = {'status': 'error', 'err-code': 1, 'err-message': 'test'}
        with self.assertRaises(HuobiRestiApiError):
            self.client.market_history_kline(
                symbol="btcusdt",
                period="1day",
                size=2
            )


    def test_500(self):
        self.mocked_respnse_status_code = 500
        with self.assertRaises(HuobiRestRequestError):
            self.client.market_history_kline(
                symbol="btcusdt",
                period="1day",
                size=2
            )


"""
class of Huobi restful api client
"""
from huobi.rest.endpoints.common import HuobiRestClientCommon
from huobi.rest.endpoints.market import HuobiRestClientMarket
from huobi.rest.endpoints.account import HuobiRestClientAccounts
from huobi.rest.endpoints.order import HuobiRestClientOrder


class HuobiRestClient(
    HuobiRestClientMarket,
    HuobiRestClientCommon,
    HuobiRestClientAccounts,
    HuobiRestClientOrder,
):
    """
    Huobi restful api client
    """
    pass
